==> modx-cms-1.0.3.zip: modx-1.0.3/assets/plugins/tinymce/lang/russian-UTF8.inc.php <==
<?php
/*
 * Filename:       assets/plugins/tinymce/lang/russian-UTF8.inc.php
 * Function:       Russian language file for TinyMCE
 * Encoding:       UTF-8
 * Author:         Jeff Whitfield / translated by Victor Safronovich
 * Date:           29.06.2008
 * Version:        0.9.6.2
 * MODx version:   0.9.6.2
 */

$_lang['tinymce_editor_theme_title'] = "Тема WYSIWYG-редактора:";
$_lang['tinymce_editor_theme_message'] = "Выберите какую тему или шаблон вы будете использовать для WYSIWYG-редактора.";
$_lang['tinymce_editor_custom_plugins_title'] = "Индивидуальные плагины:";
$_lang['tinymce_editor_custom_plugins_message'] = "Введите, через запятую, плагины для &laquo;Индивидуальной&raquo; темы.";
$_lang['tinymce_editor_custom_buttons_title'] = "Индивидуальные кнопки:";
$_lang['tinymce_editor_custom_buttons_message'] = "Введите, через запятую, кнопки для &laquo;Индивидуальной&raquo; темы. Убедитесь что дополнения, к которым относятся данные кнопки, прописанны в настройке &laquo;Индивидуальные плагины&raquo;.";
$_lang['tinymce_editor_css_selectors_title'] = "Селекторы CSS:";
$_lang['tinymce_editor_css_selectors_message'] = "Введите список селекторов, который будет доступен в WYSIWYG-редакторе. Введите их следующим образом:<br />&laquo;имя, которое будет показано в WYSIWYG-редакторе&raquo;=&laquo;имя селектора&raquo;;displayName2=selectorName2<br />Например, в вашем CSS файле есть <b>.mono</b> и <b>.smallText</b> селекторы, чтобы их добавить надо прописать:<br />'Монохромный текст=mono;Мелкий текст=smallText'<br />NB: не ставьте точку с запятой(;) после последней записи.";
$_lang['tinymce_settings'] = "Настройки TinyMCE";
$_lang['tinymce_theme_simple'] = "Простая";
$_lang['tinymce_theme_advanced'] = "Продвинутая";
$_lang['tinymce_theme_editor'] = "Редактор контента";
$_lang['tinymce_theme_custom'] = "Индивидуальная";
$_lang['tinymce_theme_creative'] = 'Creative';
$_lang['tinymce_theme_logic'] = 'xhtml';
$_lang['tinymce_theme_global_settings'] = "Использовать глобальные настройки";
?>

==> modx-cms-1.0.7.zip: modx-1.0.7/assets/plugins/tinymce/lang/russian-UTF8.inc.php <==
<?php
/*
 * Filename:       assets/plugins/tinymce/lang/russian-UTF8.inc.php
 * Function:       Russian language file for TinyMCE
 * Encoding:       UTF-8
 * Author:         Jeff Whitfield / translated by Victor Safronovich
 * Date:           13.01.2010
 * MODx version:   1.0.5
 */

$_lang['tinymce_editor_theme_title'] = "Тема WYSIWYG-редактора:";
$_lang['tinymce_editor_theme_message'] = "Выберите какую тему или шаблон вы будете использовать для WYSIWYG-редактора.";
$_lang['tinymce_editor_custom_plugins_title'] = "Индивидуальные плагины:";
$_lang['tinymce_editor_custom_plugins_message'] = "Введите, через запятую, плагины для &laquo;Индивидуальной&raquo; темы.";
$_lang['tinymce_editor_custom_buttons_title'] = "Индивидуальные кнопки:";
$_lang['tinymce_editor_custom_buttons_message'] = "Введите, через запятую, кнопки для &laquo;Индивидуальной&raquo; темы. Убедитесь что дополнения, к которым относятся данные кнопки, прописанны в настройке &laquo;Индивидуальные плагины&raquo;.";
$_lang['tinymce_editor_css_selectors_title'] = "Селекторы CSS:";
$_lang['tinymce_editor_css_selectors_message'] = "Введите список селекторов, который будет доступен в WYSIWYG-редакторе. Введите их следующим образом:<br />&laquo;имя, которое будет показано в WYSIWYG-редакторе&raquo;=&laquo;имя селектора&raquo;;displayName2=selectorName2<br />Например, в вашем CSS файле есть <b>.mono</b> и <b>.smallText</b> селекторы, чтобы их добавить надо прописать:<br />'Монохромный текст=mono;Мелкий текст=smallText'<br />NB: не ставьте точку с запятой(;) после последней записи.";
$_lang['tinymce_settings'] = "Настройки TinyMCE";
$_lang['tinymce_theme_simple'] = "Простая";
$_lang['tinymce_theme_advanced'] = "Продвинутая";
$_lang['tinymce_theme_editor'] = "Редактор контента";
$_lang['tinymce_theme_custom'] = "Индивидуальная";
$_lang['tinymce_theme_creative'] = 'Creative';
$_lang['tinymce_theme_logic'] = 'xhtml';
$_lang['tinymce_theme_global_settings'] = "Использовать глобальные настройки";
?>
